@@ -1,7 +1,7 @@
 // qsampler.cpp
 //
 /****************************************************************************
-   Copyright (C) 2004-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2004-2022, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2007,2008,2015,2019 Christian Schoenebeck
 
    This program is free software; you can redistribute it and/or
@@ -35,6 +35,20 @@
 #include <QTranslator>
 #include <QLocale>
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+#include <lscp/client.h>
+#ifdef CONFIG_LIBGIG
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-parameter"
+#endif
+#include <gig.h>
+#if defined(Q_CC_GNU) || defined(Q_CC_MINGW)
+#pragma GCC diagnostic pop
+#endif
+#endif
+#endif
+
 #if defined(__APPLE__)  // Toshi Nagata 20080105
 #include <QDir>
 #endif
@@ -43,6 +57,10 @@
 #define CONFIG_PREFIX	"/usr/local"
 #endif
 
+#ifndef CONFIG_BINDIR
+#define CONFIG_BINDIR	CONFIG_PREFIX "/bin"
+#endif
+
 #ifndef CONFIG_DATADIR
 #define CONFIG_DATADIR	CONFIG_PREFIX "/share"
 #endif
@@ -106,6 +124,27 @@ qsamplerApplication::qsamplerApplication ( int& argc, char **argv )
 	QApplication::setApplicationName(QSAMPLER_TITLE);
 	QApplication::setApplicationDisplayName(QSAMPLER_TITLE);
 	//	QSAMPLER_TITLE " - " + QObject::tr(QSAMPLER_SUBTITLE));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+	QApplication::setDesktopFileName(
+		QString("org.rncbc.%1").arg(PACKAGE_TARNAME));
+#endif
+	QString sVersion(CONFIG_BUILD_VERSION);
+	sVersion += '\n';
+	sVersion += QString("Qt: %1").arg(qVersion());
+#if defined(QT_STATIC)
+	sVersion += "-static";
+#endif
+	sVersion += '\n';
+#ifdef CONFIG_LIBGIG
+	sVersion += QString("%1: %2")
+		.arg(gig::libraryName().c_str())
+		.arg(gig::libraryVersion().c_str());
+	sVersion += '\n';
+#endif
+	sVersion += QString("%1: %2")
+		.arg(::lscp_client_package())
+		.arg(::lscp_client_version());
+	QApplication::setApplicationVersion(sVersion);
 #endif
 	// Load translation support.
 	QLocale loc;
@@ -121,23 +160,25 @@ qsamplerApplication::qsamplerApplication ( int& argc, char **argv )
 		if (m_pQtTranslator->load(sLocName, sLocPath)) {
 			QApplication::installTranslator(m_pQtTranslator);
 		} else {
+			sLocPath = QApplication::applicationDirPath();
 		#ifdef RELATIVE_LOCALE_DIR
-			sLocPath = QApplication::applicationDirPath() + RELATIVE_LOCALE_DIR;
+			sLocPath.append(RELATIVE_LOCALE_DIR);
+		#else
+			sLocPath.remove(CONFIG_BINDIR);
+			sLocPath.append(CONFIG_DATADIR "/qsampler/translations");
+		#endif
 			if (m_pQtTranslator->load(sLocName, sLocPath)) {
 				QApplication::installTranslator(m_pQtTranslator);
 			} else {
-		#endif
-			delete m_pQtTranslator;
-			m_pQtTranslator = nullptr;
-		#ifdef CONFIG_DEBUG
-			qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
-				loc.name().toUtf8().constData(),
-				sLocPath.toUtf8().constData(),
-				sLocName.toUtf8().constData());
-		#endif
-		#ifdef RELATIVE_LOCALE_DIR
+				delete m_pQtTranslator;
+				m_pQtTranslator = nullptr;
+			#ifdef CONFIG_DEBUG
+				qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
+					loc.name().toUtf8().constData(),
+					sLocPath.toUtf8().constData(),
+					sLocName.toUtf8().constData());
+			#endif
 			}
-		#endif
 		}
 		// Try own application translation...
 		m_pMyTranslator = new QTranslator(this);
@@ -489,7 +530,7 @@ int main ( int argc, char **argv )
 	::signal(SIGBUS,  stacktrace);
 #endif
 #endif
-#if defined(Q_OS_LINUX)
+#if defined(Q_OS_LINUX) && !defined(CONFIG_WAYLAND)
 	::setenv("QT_QPA_PLATFORM", "xcb", 0);
 #endif
 #if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
